local LDB
local parent = CreateFrame('Frame')

 -- Get a reference to the lib
local LibQTip = LibStub('LibQTip-1.0')
local tooltip = nil

local function UpdateDisplay()	
	if lastpetId ~= nil then
		LDB.text = lastpetText
		LDB.icon = lastpetIcon
	end
	
	local summonedPetID = C_PetJournal.GetSummonedPetID();
		
	if summonedPetID then
		local speciesID, customName, petlevel, xp, maxXp, displayID, petName, petIcon, petType, creatureID = C_PetJournal.GetPetInfoByPetID(summonedPetID)
		local creatureName = petName
			if customName then
				creatureName = customName
			end
			if creatureName then
			LDB.text = format("|cff00ff00%s|r", creatureName)
			LDB.icon = petIcon
			lastpetText = creatureName
			lastpetId = summonedPetID
			lastpetIcon = petIcon
			return
			end
	end
	
end

local function ModifiedClick(button, Id)
local speciesID, customName, petlevel, xp, maxXp, displayID, petName, petIcon, petType, creatureID = C_PetJournal.GetPetInfoByPetID(Id)
	local creatureName = petName
		if customName then
			creatureName = customName
		end
	
	if IsShiftKeyDown() then
		C_PetJournal.PickupPet(Id);
	elseif IsAltKeyDown() and not IsControlKeyDown() then
		fav1id = Id
		DEFAULT_CHAT_FRAME:AddMessage(string.format("|cffffff00BrokerPets:|r %s added as favorite 1.", creatureName))
	elseif IsControlKeyDown() and not IsAltKeyDown() then
		fav2id = Id
		DEFAULT_CHAT_FRAME:AddMessage(string.format("|cffffff00BrokerPets:|r %s added as favorite 2.", creatureName))
	elseif IsControlKeyDown() and IsAltKeyDown() then
		fav3id = Id
		DEFAULT_CHAT_FRAME:AddMessage(string.format("|cffffff00BrokerPets:|r %s added as favorite 3.", creatureName))
	else
		C_PetJournal.SummonPetByID(Id);
	end
	LibQTip:Release(tooltip)
	tooltip = nil
end

local function OnTooltipShow(self)
	if tooltip and tooltip:IsShown() then
	LibQTip:Release(tooltip)
	tooltip = nil
	end
	local numPets, numOwned = C_PetJournal.GetNumPets(false);
	self:AddLine('|cff00ffffBrokerPets|r')
	self:AddLine("<Right Click> to open pet list")
	self:AddLine("<Left Click> to summon/dismiss pet")
	self:AddLine("<Shift-Left Click> plugin to open pet journal")
	self:AddLine("<Shift-Right Click> plugin to open filter menu")
	self:AddLine("<Shift-Left Click> pet to pick it up")
	if fav1id then
	local speciesID, customName, petlevel, xp, maxXp, displayID, petName, petIcon, petType, creatureID = C_PetJournal.GetPetInfoByPetID(fav1id)
	local creatureName = petName
		if customName then
			creatureName = customName
		end	
		self:AddLine(format("<ALT-Click> |T%s:16|t%s", petIcon, creatureName))
	else
		self:AddLine("<ALT-Click> pet to set as favorite 1")
	end
	if fav2id then
	local speciesID, customName, petlevel, xp, maxXp, displayID, petName, petIcon, petType, creatureID = C_PetJournal.GetPetInfoByPetID(fav2id)
	local creatureName = petName
		if customName then
			creatureName = customName
		end	
		self:AddLine(format("<CTRL-Click> |T%s:16|t%s", petIcon, creatureName))
	else
		self:AddLine("<CTRL-Click> pet to set as favorite 2")
	end
	if fav3id then
	local speciesID, customName, petlevel, xp, maxXp, displayID, petName, petIcon, petType, creatureID = C_PetJournal.GetPetInfoByPetID(fav3id)
	local creatureName = petName
		if customName then
			creatureName = customName
		end	
		self:AddLine(format("<CTRL-ALT-Click> |T%s:16|t%s", petIcon, creatureName))
	else
	self:AddLine("<CTRL-ALT-Click> pet to set as favorite 3")
	end
	if numOwned == 0 then
	self:AddLine("|cffff0000You have no pets|r")
	else
	self:AddLine(string.format("|cff00ff00You have %s pets|r", numOwned))
	end
end

local function anchor_OnEnter(self)
   -- Acquire a tooltip with 1 columns, aligned to left
tooltip = LibQTip:Acquire("BrokerMountsTooltip", 1, "LEFT") 
self.tooltip = tooltip 
tooltip:EnableMouse(true)
tooltip:SetAutoHideDelay(1.5, self)
  
   -- Use smart anchoring code to anchor the tooltip to our frame
tooltip:SmartAnchorTo(self)
	local numPets, numOwned = C_PetJournal.GetNumPets(false)
	local summonedPetID = C_PetJournal.GetSummonedPetID();
	for i = 1, numPets do
		local petID, speciesID, isOwned, customName, petlevel, favorite, isRevoked, name, icon, petType, creatureID, sourceText, description, isWildPet = C_PetJournal.GetPetInfoByIndex(i)
			local creatureName = name
			if customName then
				creatureName = customName
			end
		local isSummonable = C_PetJournal.PetIsSummonable(petID)
		if isOwned then
		 -- Add a new line, using all columns
			if isSummonable then
				if summonedPetID == petID then
					tooltip:AddLine(format("|T%s:16|t |cff00ff00%s|r", icon, creatureName))
					tooltip:SetCellScript(i, 1, "OnMouseUp", ModifiedClick, petID)
				else
					tooltip:AddLine(format("|T%s:16|t %s", icon, creatureName))
					tooltip:SetCellScript(i, 1, "OnMouseUp", ModifiedClick, petID)
				end
			else
				tooltip:AddLine(format("|T%s:16|t |cff848484%s|r", icon, creatureName))
			end
		end				
	end
	tooltip:UpdateScrolling(500)
		-- Show it
	if tooltip:IsShown() then
		LibQTip:Release(self.tooltip)
		self.tooltip = nil	
	else
		tooltip:Show()
	end
end
 
local function anchor_OnLeave(self)   
   -- Release the tooltip
   LibQTip:Release(self.tooltip)
   self.tooltip = nil  
end


local function OnClick(self, button)
	if (button == 'RightButton' and not IsShiftKeyDown() and not IsAltKeyDown() and not IsControlKeyDown()) then
		anchor_OnEnter(self)
	end
	if (IsShiftKeyDown() and button == 'LeftButton') then	
		TogglePetJournal()
		PetJournalParent_SetTab(PetJournalParent, 2)
		--SummonRandomCritter()
	end
	if (button == 'LeftButton' and not IsShiftKeyDown() and not IsAltKeyDown() and not IsControlKeyDown()) then	
		if lastpetId ~= nil then
			C_PetJournal.SummonPetByID(lastpetId);
		end
	end	
	if (IsShiftKeyDown() and button == 'RightButton') then
		if IsAddOnLoaded("Blizzard_PetJournal") then
			ToggleDropDownMenu(1, nil, PetJournalFilterDropDown, self, 0, 0)
		else
			local loaded, reason = LoadAddOn("Blizzard_PetJournal")
			ToggleDropDownMenu(1, nil, PetJournalFilterDropDown, self, 0, 0)
		end
	end
	if (button == 'LeftButton' and IsAltKeyDown() and not IsControlKeyDown()) then
		if fav1id ~= nil then
			C_PetJournal.SummonPetByID(fav1id)
		end
	end
	if (button == 'LeftButton' and IsControlKeyDown() and not IsAltKeyDown()) then
		if fav2id ~= nil then
			C_PetJournal.SummonPetByID(fav2id)
		end
	end
	if (button == 'LeftButton' and IsControlKeyDown() and IsAltKeyDown()) then
		if fav3id ~= nil then
			C_PetJournal.SummonPetByID(fav3id)
		end
	end
end

 -- Somewhere in the anchor initialization
parent:SetScript('OnEnter', anchor_OnEnter)
parent:SetScript('OnLeave', anchor_OnLeave)

function parent:PLAYER_LOGIN()
	LDB = LibStub('LibDataBroker-1.1'):NewDataObject('BrokerPets', {
		icon = "Interface\\Icons\\INV_Misc_QuestionMark.blp",
		text = "BrokerPets",
		type = 'data source',
		OnTooltipShow = OnTooltipShow,
		--OnEnter = anchor_OnEnter,
		OnLeave = anchor_OnLeave,
		OnClick = OnClick,
	})

	self:RegisterEvent('COMPANION_UPDATE')
	self.COMPANION_UPDATE = UpdateDisplay
	
	self:RegisterEvent("PET_JOURNAL_LIST_UPDATE")
	self.PET_JOURNAL_LIST_UPDATE = UpdateDisplay

	UpdateDisplay()
end

parent:SetScript('OnEvent', function(self, event, ...) self[event](self, ...) end)
parent:RegisterEvent('PLAYER_LOGIN')